<ion-view view-title="{{'Settings' | translate}}">
  <ion-content>
    <div class="list">
      <label class="item item-input item-select" ng-if="connections">
        <div class="input-label" translate>
          Connection
        </div>
        <select ng-model="settings.webSocketUrl"
                ng-options="url as connection.name for (url, connection) in connections"
                >
          <option value="">{{'Add Connection' | translate}}</option>
        </select>
      </label>

      <label class="item item-input item-select">
        <div class="input-label" translate>
          Language
        </div>
        <select ng-model="settings.locale"
                ng-options="id as locale.displayName for (id, locale) in locales"
                >
        </select>
      </label>

      <label class="item item-input item-select">
        <div class="input-label" translate>
          Theme
        </div>
        <select ng-model="settings.stylesheet">
          <option value="css/ionic.min.css">Ionic</option>
          <option value="css/ionic-ios.min.css">Ionic iOS</option>
        </select>
      </label>

      <label class="item item-input item-select">
        <div class="input-label" translate>
          Default Click Action
        </div>
        <select ng-model="settings.action">
          <option value="add" translate>Add to Tracklist</option>
          <option value="add+play" translate>Play Track</option>
        </select>
      </label>
    </div>

    <div class="list">
      <a class="item item-icon-right" ui-sref="tabs.logging">
        <span translate>Logging</span>
        <i class="icon icon-accessory ion-chevron-right"></i>
      </a>
    </div>
  </ion-content>
</ion-view>
