<ion-popover-view class="mopidy-mobile-menu">
  <ion-content scroll="false">
    <div class="list">
      <button class="item" ng-click="popover.hide() && play()" translate>
        Play All
      </button>
      <button class="item" ng-click="popover.hide() && add()" translate>
        Add to Tracklist
      </button>
      <button class="item" ng-click="popover.hide() && replace()" translate>
        Replace Current Tracklist
      </button>
    </div>
  </ion-content>
</ion-popover-view>
